==> php82-nextcloud-28.0.2.tgz: share/nextcloud/apps/logreader/l10n/fr.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "Journalisation",
    "Errors in the log" : "Erreurs dans le journal",
    "No errors in the logs since %s" : "Aucune erreur dans les journaux depuis %s",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["%n erreur dans les journaux depuis %s","%n erreurs dans les journaux depuis %s","%n erreurs dans les journaux depuis %s"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["%n avertissement dans les journaux depuis %s","%n avertissements dans les journaux depuis %s","%n avertissements dans les journaux depuis %s"],
    "Log Reader" : "Lecteur de journaux",
    "A log reader for Nextcloud" : "Un lecteur du fichier journal pour Nextcloud",
    "Log reader for Nextcloud" : "Lecteur du fichier journal pour Nextcloud",
    "Log reader" : "Lecteur de journaux",
    "Open log reader settings" : "Ouvrir les paramètres du lecteur de journaux",
    "Log reader settings" : "Paramètres du lecteur de journaux",
    "Currently the log file {file} is shown" : "Le fichier journal {file} est actuellement affiché",
    "Show server log" : "Afficher le journal du serveur",
    "Live view is disabled" : "La vue en direct est désactivée",
    "No log file" : "Pas de fichier journal",
    "File-based logging must be enabled to access logs from the Web UI." : "La journalisation par fichier doit être activée pour accéder aux journaux à partir de l'interface Web.",
    "Level" : "Niveau",
    "App" : "App",
    "No app in context" : "Pas d'app dans le contexte",
    "Time" : "Date et heure",
    "Copy raw entry" : "Copier l'entrée brute",
    "Copy formatted entry" : "Copier l'entrée formatée",
    "Hide exception details" : "Masquer les détails de l'exception",
    "View exception details" : "Voir les détails de l'exception",
    "Raw log entry" : "Entrée brute dans le journal",
    "Log entry successfully copied" : "Copie réussie de l'entrée du journal",
    "Search log entries" : "Rechercher des entrées dans le journal",
    "Caused by {exception}" : "Causé par {exception}",
    "Line {line}" : "Ligne {line}",
    "Filter log levels" : "Filtrage des niveaux de journalisation",
    "Set log level" : "Définir le niveau de journalisation",
    "Time format" : "Format de l'heure",
    "Live view" : "Vue en direct",
    "Download/Upload logs" : "Téléchargement/Téléversement des journaux",
    "Download logs" : "Télécharger les journaux",
    "Show local log file" : "Afficher le fichier journal local",
    "Upload local log file to be displayed" : "Téléversement le fichier journal local à afficher",
    "Could not parse local log file" : "Impossible de parser le fichier de journalisation local",
    "Raw data" : "Données brutes",
    "Local time" : "Heure locale",
    "UTC time" : "Heure UTC",
    "Time format used for displaying the timestamp" : "Format de l'heure utilisée pour afficher l'horodatage",
    "Could not change date time format." : "Impossible de changer le format de l'heure.",
    "Polling is disabled because server is not configured to log to file" : "L'interrogation est désactivée car le serveur n'est pas configuré pour journaliser dans un fichier",
    "Polling (live view)" : "Interrogation (vue en direct)",
    "Could not change live view setting." : "Impossible de changer le paramètre de vue en direct.",
    "Filter logging levels" : "Filtrer les niveaux de journalisation",
    "Application" : "Application",
    "Message" : "Message",
    "Collapse row" : "Replier la ligne",
    "Expand row" : "Étendre la ligne ",
    "Show details" : "Afficher les détails",
    "Debug" : "Déboguage",
    "Info" : "Info",
    "Warning" : "Avertissement",
    "Error" : "Erreur",
    "Fatal" : "Fatal",
    "Could not load log entries" : "Impossible de charger les entrées du journal",
    "Could not fetch new log entries (server unavailable)" : "Impossible de récupérer les nouvelles entrées du journal (serveur indisponible)",
    "Could not fetch new entries" : "Impossible de récupérer les nouvelles entrées",
    "Could not copy to clipboard, please copy manually:" : "Impossible de copier dans le presse-papiers, veuillez copier manuellement :",
    "\tfrom {address} by {user} at {time}\n" : "\tde {address} par {user} à {time}\n",
    "Error parsing log" : "Erreur lors de l'analyse du fichier journal",
    "Caused by " : "Causé par",
    "Copy" : "Copier",
    "Copy raw" : "Copie brute",
    "Copy formatted" : "Copie formatée",
    "No server logs" : "Aucun journal serveur",
    "One or more entries are hidden by the log level filter" : "Des entrées sont masquées par le filtre sur le niveau de journalisation",
    "Everything is working fine" : "Tout fonctionne à merveille",
    "Load log file" : "Charger un fichier journal",
    "Invalid log file" : "Fichier journal invalide",
    "Log levels" : "Niveaux de journalisation",
    "Log content" : "Contenu du registre",
    "Live update" : "Mise à jour en direct",
    "line {line}" : "Ligne {line}",
    "Download / Upload logs" : "Téléchargement / Téléversement des journaux"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> php82-nextcloud-28.0.6.tgz: share/nextcloud/apps/logreader/l10n/fr.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "Journalisation",
    "Errors in the log" : "Erreurs dans le journal",
    "Failed to get an iterator for log entries: %s" : "Échec de la récupération d’un itérateur pour les entrées de journal : %s",
    "No errors in the logs since %s" : "Aucune erreur dans les journaux depuis %s",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["%n erreur dans les journaux depuis %s","%n erreurs dans les journaux depuis %s","%n erreurs dans les journaux depuis %s"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["%n avertissement dans les journaux depuis %s","%n avertissements dans les journaux depuis %s","%n avertissements dans les journaux depuis %s"],
    "Log Reader" : "Lecteur de journaux",
    "A log reader for Nextcloud" : "Un lecteur du fichier journal pour Nextcloud",
    "Log reader for Nextcloud" : "Lecteur du fichier journal pour Nextcloud",
    "Log reader" : "Lecteur de journaux",
    "Open log reader settings" : "Ouvrir les paramètres du lecteur de journaux",
    "Log reader settings" : "Paramètres du lecteur de journaux",
    "Currently the log file {file} is shown" : "Le fichier journal {file} est actuellement affiché",
    "Show server log" : "Afficher le journal du serveur",
    "Live view is disabled" : "La vue en direct est désactivée",
    "No log file" : "Pas de fichier journal",
    "File-based logging must be enabled to access logs from the Web UI." : "La journalisation par fichier doit être activée pour accéder aux journaux à partir de l’interface Web.",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "Si vous pensez que c’est une erreur, veuillez vérifier {setting} dans votre {config} et de regarder le manuel de l'administration Nextcloud.",
    "Level" : "Niveau",
    "App" : "App",
    "No app in context" : "Pas d'app dans le contexte",
    "Time" : "Date et heure",
    "Copy raw entry" : "Copier l’entrée brute",
    "Copy formatted entry" : "Copier l'entrée formatée",
    "Hide exception details" : "Masquer les détails de l'exception",
    "View exception details" : "Voir les détails de l'exception",
    "Raw log entry" : "Entrée brute dans le journal",
    "Log entry successfully copied" : "Copie réussie de l’entrée du journal",
    "Search log entries" : "Rechercher des entrées dans le journal",
    "Caused by {exception}" : "Causé par {exception}",
    "Line {line}" : "Ligne {line}",
    "Filter log levels" : "Filtrage des niveaux de journalisation",
    "Set log level" : "Définir le niveau de journalisation",
    "Time format" : "Format de l'heure",
    "Live view" : "Vue en direct",
    "Download/Upload logs" : "Téléchargement/Téléversement des journaux",
    "You can also show log entries copied from your clipboard by pasting them on the log view using: {keyboardShortcut}" : "Vous pouvez aussi afficher les entrées du journal copiées depuis votre presse-papiers en les collant dans la visionneuse de journaux en utilisant : {keyboardShortcut}",
    "Download logs" : "Télécharger les journaux",
    "Show local log file" : "Afficher le fichier journal local",
    "Upload local log file to be displayed" : "Téléversement le fichier journal local à afficher",
    "Ctrl" : "Ctrl",
    "Could not parse local log file" : "Impossible de parser le fichier de journalisation local",
    "Raw data" : "Données brutes",
    "Local time" : "Heure locale",
    "UTC time" : "Heure UTC",
    "Relative" : "Relatif",
    "Time format used for displaying the timestamp" : "Format de l'heure utilisée pour afficher l'horodatage",
    "(Local log files only support the \"raw\" time format)" : "(Les fichiers journaux locaux ne prennent en charge que le format horaire \"brut\")",
    "Could not change date time format." : "Impossible de changer le format de l'heure.",
    "Polling is disabled because server is not configured to log to file" : "L'interrogation est désactivée car le serveur n'est pas configuré pour journaliser dans un fichier",
    "Polling (live view)" : "Interrogation (vue en direct)",
    "Could not change live view setting." : "Impossible de changer le paramètre de vue en direct.",
    "Filter logging levels" : "Filtrer les niveaux de journalisation",
    "Could not set logging levels to show" : "Impossible de définir les niveaux de journalisation sur afficher",
    "Set backend loglevel" : "Définir les niveaux de journalisation d'infrastructure",
    "Could not set logging level" : "Impossible de définir le niveau de journalisation",
    "Application" : "Application",
    "Message" : "Message",
    "Log entry actions" : "Actions de journalisation entrantes",
    "Loading older log entries" : "Chargement des anciennes entrées de journaux",
    "No older log entries available" : "Aucune entrée de journal plus ancienne disponible",
    "Collapse row" : "Replier la ligne",
    "Expand row" : "Étendre la ligne ",
    "Show details" : "Afficher les détails",
    "Debug" : "Déboguage",
    "Info" : "Info",
    "Warning" : "Avertissement",
    "Error" : "Erreur",
    "Fatal" : "Fatal",
    "Could not load log entries" : "Impossible de charger les entrées du journal",
    "Clipboard" : "Presse-papier",
    "Could not parse clipboard content" : "Impossible de parser le contenu du presse-papier",
    "Could not fetch new log entries (server unavailable)" : "Impossible de récupérer les nouvelles entrées du journal (serveur indisponible)",
    "Could not fetch new entries" : "Impossible de récupérer les nouvelles entrées",
    "Could not copy to clipboard, please copy manually:" : "Impossible de copier dans le presse-papiers, veuillez copier manuellement :",
    "\tfrom {address} by {user} at {time}\n" : "\tde {address} par {user} à {time}\n",
    "Error parsing log" : "Erreur lors de l'analyse du fichier journal",
    "Caused by " : "Causé par",
    "Copy" : "Copier",
    "Copy raw" : "Copie brute",
    "Copy formatted" : "Copie formatée",
    "No server logs" : "Aucun journal serveur",
    "One or more entries are hidden by the log level filter" : "Des entrées sont masquées par le filtre sur le niveau de journalisation",
    "Everything is working fine" : "Tout fonctionne à merveille",
    "Load log file" : "Charger un fichier journal",
    "Invalid log file" : "Fichier journal invalide",
    "Log levels" : "Niveaux de journalisation",
    "Log content" : "Contenu du registre",
    "Live update" : "Mise à jour en direct",
    "line {line}" : "Ligne {line}",
    "Download / Upload logs" : "Téléchargement / Téléversement des journaux"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
